# pulp_ansible_client

PulpAnsibleClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.13.4
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_ansible_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_ansible_client-0.13.4.gem
```

(for development, run `gem install --dev ./pulp_ansible_client-0.13.4.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_ansible_client', '~> 0.13.4'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_ansible_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_ansible_client'

# Setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpAnsibleClient::AnsibleCollectionsApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  namespace: 'namespace_example', # String | 
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List collections
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling AnsibleCollectionsApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpAnsibleClient::AnsibleCollectionsApi* | [**list**](docs/AnsibleCollectionsApi.md#list) | **GET** /pulp/api/v3/ansible/collections/ | List collections
*PulpAnsibleClient::AnsibleCollectionsApi* | [**upload_collection**](docs/AnsibleCollectionsApi.md#upload_collection) | **POST** /ansible/collections/ | Upload a collection
*PulpAnsibleClient::AnsibleCopyApi* | [**copy_content**](docs/AnsibleCopyApi.md#copy_content) | **POST** /pulp/api/v3/ansible/copy/ | Copy content
*PulpAnsibleClient::ApiCollectionsApi* | [**get**](docs/ApiCollectionsApi.md#get) | **GET** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiCollectionsApi* | [**post**](docs/ApiCollectionsApi.md#post) | **POST** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiRolesApi* | [**get**](docs/ApiRolesApi.md#get) | **GET** {ansible_role_href}api/v1/roles/ | 
*PulpAnsibleClient::CollectionImportApi* | [**read**](docs/CollectionImportApi.md#read) | **GET** {ansible_collection_import_href} | Inspect a collection import
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**create**](docs/ContentCollectionDeprecationsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_deprecations/ | Create an ansible collection deprecated
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**list**](docs/ContentCollectionDeprecationsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_deprecations/ | List ansible collection deprecateds
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**read**](docs/ContentCollectionDeprecationsApi.md#read) | **GET** {ansible_ansible_collection_deprecated_href} | Inspect an ansible collection deprecated
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**create**](docs/ContentCollectionSignaturesApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_signatures/ | Create a collection version signature
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**list**](docs/ContentCollectionSignaturesApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_signatures/ | List collection version signatures
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**read**](docs/ContentCollectionSignaturesApi.md#read) | **GET** {ansible_collection_version_signature_href} | Inspect a collection version signature
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**create**](docs/ContentCollectionVersionsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_versions/ | Create a collection version
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**list**](docs/ContentCollectionVersionsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_versions/ | List collection versions
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**read**](docs/ContentCollectionVersionsApi.md#read) | **GET** {ansible_collection_version_href} | Inspect a collection version
*PulpAnsibleClient::ContentRolesApi* | [**create**](docs/ContentRolesApi.md#create) | **POST** /pulp/api/v3/content/ansible/roles/ | Create a role
*PulpAnsibleClient::ContentRolesApi* | [**list**](docs/ContentRolesApi.md#list) | **GET** /pulp/api/v3/content/ansible/roles/ | List roles
*PulpAnsibleClient::ContentRolesApi* | [**read**](docs/ContentRolesApi.md#read) | **GET** {ansible_role_href} | Inspect a role
*PulpAnsibleClient::DistributionsAnsibleApi* | [**create**](docs/DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**delete**](docs/DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_ansible_distribution_href} | Delete an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**list**](docs/DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
*PulpAnsibleClient::DistributionsAnsibleApi* | [**partial_update**](docs/DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**read**](docs/DistributionsAnsibleApi.md#read) | **GET** {ansible_ansible_distribution_href} | Inspect an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**update**](docs/DistributionsAnsibleApi.md#update) | **PUT** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::GalaxyDetailApi* | [**get**](docs/GalaxyDetailApi.md#get) | **GET** {ansible_collection_href} | 
*PulpAnsibleClient::PulpAnsibleApiApi* | [**get**](docs/PulpAnsibleApiApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/ | 
*PulpAnsibleClient::PulpAnsibleApiV2CollectionsVersionsApi* | [**get**](docs/PulpAnsibleApiV2CollectionsVersionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v2/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3Api* | [**read**](docs/PulpAnsibleApiV3Api.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/ | 
*PulpAnsibleClient::PulpAnsibleApiV3ArtifactsCollectionsApi* | [**get**](docs/PulpAnsibleApiV3ArtifactsCollectionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/{path}/{filename} | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionVersionsAllApi* | [**list**](docs/PulpAnsibleApiV3CollectionVersionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collection_versions/all/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**delete**](docs/PulpAnsibleApiV3CollectionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**list**](docs/PulpAnsibleApiV3CollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**read**](docs/PulpAnsibleApiV3CollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**update**](docs/PulpAnsibleApiV3CollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsAllApi* | [**list**](docs/PulpAnsibleApiV3CollectionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/all/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**delete**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**list**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**read**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleApiV3CollectionsVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi* | [**download**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi.md#download) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/{filename} | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**delete**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**update**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**delete**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create) | **POST** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_0**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_0) | **POST** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_1**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_1) | **POST** /pulp_ansible/galaxy/default/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_2**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_2) | **POST** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleDefaultApiApi* | [**get**](docs/PulpAnsibleDefaultApiApi.md#get) | **GET** /pulp_ansible/galaxy/default/api/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3Api* | [**read**](docs/PulpAnsibleDefaultApiV3Api.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3ArtifactsCollectionsApi* | [**get**](docs/PulpAnsibleDefaultApiV3ArtifactsCollectionsApi.md#get) | **GET** /pulp_ansible/galaxy/default/api/v3/artifacts/collections/{path}/{filename} | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionVersionsAllApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionVersionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collection_versions/all/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**update**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsAllApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/all/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi* | [**download**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi.md#download) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/{filename} | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**delete**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**update**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#update) | **PATCH** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleTagsApi* | [**list**](docs/PulpAnsibleTagsApi.md#list) | **GET** /pulp/api/v3/pulp_ansible/tags/ | List tags
*PulpAnsibleClient::RemotesCollectionApi* | [**create**](docs/RemotesCollectionApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/collection/ | Create a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**delete**](docs/RemotesCollectionApi.md#delete) | **DELETE** {ansible_collection_remote_href} | Delete a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**list**](docs/RemotesCollectionApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/collection/ | List collection remotes
*PulpAnsibleClient::RemotesCollectionApi* | [**partial_update**](docs/RemotesCollectionApi.md#partial_update) | **PATCH** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**read**](docs/RemotesCollectionApi.md#read) | **GET** {ansible_collection_remote_href} | Inspect a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**update**](docs/RemotesCollectionApi.md#update) | **PUT** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesGitApi* | [**create**](docs/RemotesGitApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/git/ | Create a git remote
*PulpAnsibleClient::RemotesGitApi* | [**delete**](docs/RemotesGitApi.md#delete) | **DELETE** {ansible_git_remote_href} | Delete a git remote
*PulpAnsibleClient::RemotesGitApi* | [**list**](docs/RemotesGitApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/git/ | List git remotes
*PulpAnsibleClient::RemotesGitApi* | [**partial_update**](docs/RemotesGitApi.md#partial_update) | **PATCH** {ansible_git_remote_href} | Update a git remote
*PulpAnsibleClient::RemotesGitApi* | [**read**](docs/RemotesGitApi.md#read) | **GET** {ansible_git_remote_href} | Inspect a git remote
*PulpAnsibleClient::RemotesGitApi* | [**update**](docs/RemotesGitApi.md#update) | **PUT** {ansible_git_remote_href} | Update a git remote
*PulpAnsibleClient::RemotesRoleApi* | [**create**](docs/RemotesRoleApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/role/ | Create a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**delete**](docs/RemotesRoleApi.md#delete) | **DELETE** {ansible_role_remote_href} | Delete a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**list**](docs/RemotesRoleApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/role/ | List role remotes
*PulpAnsibleClient::RemotesRoleApi* | [**partial_update**](docs/RemotesRoleApi.md#partial_update) | **PATCH** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**read**](docs/RemotesRoleApi.md#read) | **GET** {ansible_role_remote_href} | Inspect a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**update**](docs/RemotesRoleApi.md#update) | **PUT** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**create**](docs/RepositoriesAnsibleApi.md#create) | **POST** /pulp/api/v3/repositories/ansible/ansible/ | Create an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**delete**](docs/RepositoriesAnsibleApi.md#delete) | **DELETE** {ansible_ansible_repository_href} | Delete an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**list**](docs/RepositoriesAnsibleApi.md#list) | **GET** /pulp/api/v3/repositories/ansible/ansible/ | List ansible repositorys
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**modify**](docs/RepositoriesAnsibleApi.md#modify) | **POST** {ansible_ansible_repository_href}modify/ | Modify Repository Content
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**partial_update**](docs/RepositoriesAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**read**](docs/RepositoriesAnsibleApi.md#read) | **GET** {ansible_ansible_repository_href} | Inspect an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**sign**](docs/RepositoriesAnsibleApi.md#sign) | **POST** {ansible_ansible_repository_href}sign/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**sync**](docs/RepositoriesAnsibleApi.md#sync) | **POST** {ansible_ansible_repository_href}sync/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**update**](docs/RepositoriesAnsibleApi.md#update) | **PUT** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**delete**](docs/RepositoriesAnsibleVersionsApi.md#delete) | **DELETE** {ansible_ansible_repository_version_href} | Delete a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**list**](docs/RepositoriesAnsibleVersionsApi.md#list) | **GET** {ansible_ansible_repository_href}versions/ | List repository versions
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**read**](docs/RepositoriesAnsibleVersionsApi.md#read) | **GET** {ansible_ansible_repository_version_href} | Inspect a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**repair**](docs/RepositoriesAnsibleVersionsApi.md#repair) | **POST** {ansible_ansible_repository_version_href}repair/ | 
*PulpAnsibleClient::VersionsApi* | [**get**](docs/VersionsApi.md#get) | **GET** {ansible_role_href}versions/ | 
*PulpAnsibleClient::VersionsApi* | [**get_0**](docs/VersionsApi.md#get_0) | **GET** {ansible_collection_version_href}versions/ | 


## Documentation for Models

 - [PulpAnsibleClient::AnsibleAnsibleDistribution](docs/AnsibleAnsibleDistribution.md)
 - [PulpAnsibleClient::AnsibleAnsibleDistributionResponse](docs/AnsibleAnsibleDistributionResponse.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepository](docs/AnsibleAnsibleRepository.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepositoryResponse](docs/AnsibleAnsibleRepositoryResponse.md)
 - [PulpAnsibleClient::AnsibleCollection](docs/AnsibleCollection.md)
 - [PulpAnsibleClient::AnsibleCollectionRemote](docs/AnsibleCollectionRemote.md)
 - [PulpAnsibleClient::AnsibleCollectionRemoteResponse](docs/AnsibleCollectionRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionResponse](docs/AnsibleCollectionResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersion](docs/AnsibleCollectionVersion.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionResponse](docs/AnsibleCollectionVersionResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionSignature](docs/AnsibleCollectionVersionSignature.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionSignatureResponse](docs/AnsibleCollectionVersionSignatureResponse.md)
 - [PulpAnsibleClient::AnsibleGitRemote](docs/AnsibleGitRemote.md)
 - [PulpAnsibleClient::AnsibleGitRemoteResponse](docs/AnsibleGitRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleRepositorySignature](docs/AnsibleRepositorySignature.md)
 - [PulpAnsibleClient::AnsibleRepositorySyncURL](docs/AnsibleRepositorySyncURL.md)
 - [PulpAnsibleClient::AnsibleRole](docs/AnsibleRole.md)
 - [PulpAnsibleClient::AnsibleRoleRemote](docs/AnsibleRoleRemote.md)
 - [PulpAnsibleClient::AnsibleRoleRemoteResponse](docs/AnsibleRoleRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleRoleResponse](docs/AnsibleRoleResponse.md)
 - [PulpAnsibleClient::AnsibleTagResponse](docs/AnsibleTagResponse.md)
 - [PulpAnsibleClient::ArtifactRefResponse](docs/ArtifactRefResponse.md)
 - [PulpAnsibleClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpAnsibleClient::CollectionImportDetailResponse](docs/CollectionImportDetailResponse.md)
 - [PulpAnsibleClient::CollectionMetadataResponse](docs/CollectionMetadataResponse.md)
 - [PulpAnsibleClient::CollectionNamespaceResponse](docs/CollectionNamespaceResponse.md)
 - [PulpAnsibleClient::CollectionOneShot](docs/CollectionOneShot.md)
 - [PulpAnsibleClient::CollectionRefResponse](docs/CollectionRefResponse.md)
 - [PulpAnsibleClient::CollectionResponse](docs/CollectionResponse.md)
 - [PulpAnsibleClient::CollectionVersionDocsResponse](docs/CollectionVersionDocsResponse.md)
 - [PulpAnsibleClient::CollectionVersionListResponse](docs/CollectionVersionListResponse.md)
 - [PulpAnsibleClient::CollectionVersionResponse](docs/CollectionVersionResponse.md)
 - [PulpAnsibleClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpAnsibleClient::Copy](docs/Copy.md)
 - [PulpAnsibleClient::GalaxyCollection](docs/GalaxyCollection.md)
 - [PulpAnsibleClient::GalaxyCollectionResponse](docs/GalaxyCollectionResponse.md)
 - [PulpAnsibleClient::GalaxyCollectionVersionResponse](docs/GalaxyCollectionVersionResponse.md)
 - [PulpAnsibleClient::GalaxyRoleResponse](docs/GalaxyRoleResponse.md)
 - [PulpAnsibleClient::GalaxyRoleVersionResponse](docs/GalaxyRoleVersionResponse.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseList](docs/PaginatedCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseListLinks](docs/PaginatedCollectionResponseListLinks.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseListMeta](docs/PaginatedCollectionResponseListMeta.md)
 - [PulpAnsibleClient::PaginatedCollectionVersionListResponseList](docs/PaginatedCollectionVersionListResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionResponseList](docs/PaginatedGalaxyCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionVersionResponseList](docs/PaginatedGalaxyCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleResponseList](docs/PaginatedGalaxyRoleResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleVersionResponseList](docs/PaginatedGalaxyRoleVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedTagResponseList](docs/PaginatedTagResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleDistributionResponseList](docs/PaginatedansibleAnsibleDistributionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleRepositoryResponseList](docs/PaginatedansibleAnsibleRepositoryResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionRemoteResponseList](docs/PaginatedansibleCollectionRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionResponseList](docs/PaginatedansibleCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionResponseList](docs/PaginatedansibleCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionSignatureResponseList](docs/PaginatedansibleCollectionVersionSignatureResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleGitRemoteResponseList](docs/PaginatedansibleGitRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleRemoteResponseList](docs/PaginatedansibleRoleRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleResponseList](docs/PaginatedansibleRoleResponseList.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleDistribution](docs/PatchedansibleAnsibleDistribution.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleRepository](docs/PatchedansibleAnsibleRepository.md)
 - [PulpAnsibleClient::PatchedansibleCollectionRemote](docs/PatchedansibleCollectionRemote.md)
 - [PulpAnsibleClient::PatchedansibleGitRemote](docs/PatchedansibleGitRemote.md)
 - [PulpAnsibleClient::PatchedansibleRoleRemote](docs/PatchedansibleRoleRemote.md)
 - [PulpAnsibleClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpAnsibleClient::Repair](docs/Repair.md)
 - [PulpAnsibleClient::RepoMetadataResponse](docs/RepoMetadataResponse.md)
 - [PulpAnsibleClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpAnsibleClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpAnsibleClient::TagResponse](docs/TagResponse.md)
 - [PulpAnsibleClient::UnpaginatedCollectionVersionResponse](docs/UnpaginatedCollectionVersionResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

