# PulpAnsibleClient::RemotesGitApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesGitApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/git/ | Create a git remote
[**delete**](RemotesGitApi.md#delete) | **DELETE** {ansible_git_remote_href} | Delete a git remote
[**list**](RemotesGitApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/git/ | List git remotes
[**partial_update**](RemotesGitApi.md#partial_update) | **PATCH** {ansible_git_remote_href} | Update a git remote
[**read**](RemotesGitApi.md#read) | **GET** {ansible_git_remote_href} | Inspect a git remote
[**update**](RemotesGitApi.md#update) | **PUT** {ansible_git_remote_href} | Update a git remote



## create

> AnsibleGitRemoteResponse create(ansible_git_remote)

Create a git remote

ViewSet for Ansible Remotes.  This is a tech preview feature. The functionality may change in the future.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
ansible_git_remote = PulpAnsibleClient::AnsibleGitRemote.new # AnsibleGitRemote | 

begin
  #Create a git remote
  result = api_instance.create(ansible_git_remote)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_git_remote** | [**AnsibleGitRemote**](AnsibleGitRemote.md)|  | 

### Return type

[**AnsibleGitRemoteResponse**](AnsibleGitRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ansible_git_remote_href)

Delete a git remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
ansible_git_remote_href = 'ansible_git_remote_href_example' # String | 

begin
  #Delete a git remote
  result = api_instance.delete(ansible_git_remote_href)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_git_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedansibleGitRemoteResponseList list(opts)

List git remotes

ViewSet for Ansible Remotes.  This is a tech preview feature. The functionality may change in the future.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | ISO 8601 formatted dates are supported
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List git remotes
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| ISO 8601 formatted dates are supported | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedansibleGitRemoteResponseList**](PaginatedansibleGitRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ansible_git_remote_href, patchedansible_git_remote)

Update a git remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
ansible_git_remote_href = 'ansible_git_remote_href_example' # String | 
patchedansible_git_remote = PulpAnsibleClient::PatchedansibleGitRemote.new # PatchedansibleGitRemote | 

begin
  #Update a git remote
  result = api_instance.partial_update(ansible_git_remote_href, patchedansible_git_remote)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_git_remote_href** | **String**|  | 
 **patchedansible_git_remote** | [**PatchedansibleGitRemote**](PatchedansibleGitRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> AnsibleGitRemoteResponse read(ansible_git_remote_href, opts)

Inspect a git remote

ViewSet for Ansible Remotes.  This is a tech preview feature. The functionality may change in the future.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
ansible_git_remote_href = 'ansible_git_remote_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a git remote
  result = api_instance.read(ansible_git_remote_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_git_remote_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleGitRemoteResponse**](AnsibleGitRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(ansible_git_remote_href, ansible_git_remote)

Update a git remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::RemotesGitApi.new
ansible_git_remote_href = 'ansible_git_remote_href_example' # String | 
ansible_git_remote = PulpAnsibleClient::AnsibleGitRemote.new # AnsibleGitRemote | 

begin
  #Update a git remote
  result = api_instance.update(ansible_git_remote_href, ansible_git_remote)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling RemotesGitApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_git_remote_href** | **String**|  | 
 **ansible_git_remote** | [**AnsibleGitRemote**](AnsibleGitRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

